==> dezyne-2.15.0.tar.gz: dezyne-2.15.0/test/all/blocking_multiple_provides3/main.cc <==
// Dezyne --- Dezyne command line tools
//
// Copyright © 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
// Copyright © 2021, 2022 Rutger (regtur) van Beusekom <rutger@dezyne.org>
// Copyright © 2022 Paul Hoogendijk <paul@dezyne.org>
//
// This file is part of Dezyne.
//
// Dezyne is free software: you can redistribute it and/or modify it
// under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Dezyne is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with Dezyne.  If not, see <http://www.gnu.org/licenses/>.
//
// Commentary:
//
// Code:

#include "blocking_multiple_provides3.hh"

#include <limits>
#include <thread>

#include <dzn/locator.hh>
#include <dzn/runtime.hh>
#include <dzn/pump.hh>

int main ()
{
  std::cin.ignore (std::numeric_limits<std::streamsize>::max ());

  dzn::locator locator;
  dzn::runtime runtime;
  blocking_multiple_provides3 sut (locator.set (runtime));
  dzn::pump pump;
  locator.set(pump);

  sut.dzn_meta.name = "sut";

  sut.r.in.hello = [&]
  {
    std::clog << "sut.bmp.r.hello -> <external>.r.hello\n";
    sut.hsb.r.out.world ();
    std::clog << "sut.bmp.r.return -> <external>.r.return\n";
  };

  sut.h_left.in.hello ();
  sut.h_right.in.hello ();
}

==> dezyne-2.16.5.tar.gz: dezyne-2.16.5/test/all/blocking_multiple_provides3/main.cc <==
// Dezyne --- Dezyne command line tools
//
// Copyright © 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
// Copyright © 2021, 2022 Rutger (regtur) van Beusekom <rutger@dezyne.org>
// Copyright © 2022 Paul Hoogendijk <paul@dezyne.org>
//
// This file is part of Dezyne.
//
// Dezyne is free software: you can redistribute it and/or modify it
// under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Dezyne is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public
// License along with Dezyne.  If not, see <http://www.gnu.org/licenses/>.
//
// Commentary:
//
// Code:

#include "blocking_multiple_provides3.hh"

#include <limits>
#include <thread>

#include <dzn/locator.hh>
#include <dzn/runtime.hh>
#include <dzn/pump.hh>

int main ()
{
  std::cin.ignore (std::numeric_limits<std::streamsize>::max ());

  dzn::locator locator;
  dzn::runtime runtime;
  blocking_multiple_provides3 sut (locator.set (runtime));
  dzn::pump pump;
  locator.set(pump);

  sut.dzn_meta.name = "sut";

  sut.r.in.hello = [&]
  {
    std::clog << "sut.mp.r.hello -> <external>.r.hello\n";
    sut.mp.r.out.world (); //side step going through pump, since we are
                           //already executing on the pump and the
                           //interface of r is synchronous
    std::clog << "sut.mp.r.return -> <external>.r.return\n";
  };

  sut.left.in.hello ();
  sut.right.in.hello ();
}
